<?php

/**
 * Apr Settings Options
 */
if (!class_exists('Framework_Apr_Settings')) {

    class Framework_Apr_Settings {

        public $ReduxFramework;

        public function __construct() {

            if (!class_exists('ReduxFramework')) {
                return;
            }

            // This is needed. Bah WordPress bugs.  ;)
            if (true == Redux_Helpers::isTheme(__FILE__)) {
                $this->initSettings();
            } else {
                add_action('plugins_loaded', array($this, 'initSettings'), 10);
            }
        }

        public function initSettings() {
            $this->ReduxFramework = new ReduxFramework($this->apr_get_setting_sections(), $this->apr_get_setting_arguments());
        }

        public function apr_get_setting_sections() {
            $page_layout = apr_layouts();
            $sidebar_positions = apr_sidebar_position();
            $block_name = apr_get_block_name();
            $breadcrumbs_type = apr_get_breadcrumbs_type();
            unset($page_layout['default']);
            unset($sidebar_positions['default']);
            $menus = get_terms('nav_menu');
            $menu_list =apr_list_menu();            
            $sections = array(
                array(
                    'icon' => 'el-icon-edit',
                    'icon_class' => 'icon',
                    'title' => esc_html__('General', 'bonfire'),
                    'fields' => array(
                    )
                ),
                array(
                'icon_class' => 'icon',
                'subsection' => true,
                'title' => esc_html__('Layout', 'bonfire'),
                'fields' => array(
                        array(
                            'id' => 'layout',
                            'type' => 'button_set',
                            'title' => esc_html__('Layout', 'bonfire'),
                            'options' => $page_layout,
                            'default' => 'fullwidth'
                        ),
                        array(
                            'id' => 'left-sidebar',
                            'type' => 'select',
                            'title' => esc_html__('Select Left Sidebar', 'bonfire'),
                            'data' => 'sidebars',
                            'default' => ''
                        ),
                        array(
                            'id' => 'right-sidebar',
                            'type' => 'select',
                            'title' => esc_html__('Select Right Sidebar', 'bonfire'),
                            'data' => 'sidebars',
                            'default' => ''
                        ),
                        array(
                            'id'=>'post_banner_block',
                            'type' => 'select',
                            'title' => esc_html__('Bottom Content', 'bonfire'),
                            'options' => $block_name,
                            'desc' => esc_html__('Choose a block to display at the bottom of pages. You can create a block in Static Block/Add New.', 'bonfire')
                        ),                         
                    )
                ),
                array(
                'icon_class' => 'icon',
                'subsection' => true,
                'title' => esc_html__('Logo, Favicon, Js Custom', 'bonfire'),
                'fields' => array(
                        array(
                            'id' => 'logo',
                            'type' => 'media',
                            'url' => true,
                            'readonly' => false,
                            'title' => esc_html__('Logo', 'bonfire'),
                            'required' => array(
                                        array('header-type', 'equals', array(
                                        '1','5'
                                    )),
                                ),
                            'default' => array(
                                'url' => get_template_directory_uri() . '/images/logo.png',
                                'height' => 88,
                                'wide' => 107
                            )
                        ),   
                        array(
                            'id' => 'favicon',
                            'type' => 'media',
                            'url' => true,
                            'readonly' => false,
                            'title' => esc_html__('Favicon', 'bonfire'),
                            'default' => array(
                                'url' => get_template_directory_uri() . '/images/favicon.ico'
                            )
                        ),
                        array(
                            'id' => 'js-code',
                            'type' => 'ace_editor',
                            'title' => esc_html__('JS Code', 'bonfire'),
                            'subtitle' => esc_html__('Paste your JS code here.', 'bonfire'),
                            'mode' => 'javascript',
                            'theme' => 'chrome',
                            'default' => "jQuery(document).ready(function(){});"
                        )
                    )
                ),
                array(
                'icon_class' => 'icon',
                'subsection' => true,
                'title' => esc_html__('Preloader', 'bonfire'),
                'fields' => array(
                        array(
                            'id'            => 'preload',
                            'type'          => 'button_set',
                            'title'         => esc_html__('Preload ', 'bonfire'),
                            'description'   => esc_html__('Enable Preload site', 'bonfire'), 
                            'options'       => array(
                                'enable'  => esc_html__( 'Enable', 'bonfire' ), 
                                'disable'  => esc_html__( 'Disable', 'bonfire' ),   
                            ),
                            'default'       => 'enable', 
                        ),
                        array(
                            'id'            => 'preload-type',
                            'type'          => 'image_select',
                            'title'         => esc_html__('Preload Type', 'bonfire'),
                            'subtitle' => esc_html__('Each page will have option for select preload type. Preload selection in each page will have higher priority than this general selection.','bonfire'),
                            'options' => $this->apr_preload_types(),
                            'default' => '9',
                            'required' => array(
                                    array('preload', 'equals', array(
                                    'enable'
                                )),
                            ),
                        ),
                        array(
                            'id' => 'logo-preload',
                            'type' => 'media',
                            'url' => true,
                            'readonly' => false,
                            'title' => esc_html__('Logo', 'bonfire'),
                            'default' => array(
                                'url' => get_template_directory_uri() . '/images/logo6.png'
                            ),
                            'required' => array(
                                    array('preload-type', 'equals', array(
                                    '2','5'
                                )),
                            ),
                        ),
                        array(
                            'id' => 'preloader-bg',
                            'type' => 'color',
                            'title' => esc_html__('Preload background color', 'bonfire'),
                            'validate' => 'color',
                            'default' => '', 
                            'required' => array(
                                    array('preload', 'equals', array(
                                    'enable'
                                )),
                            ),
                        ), 
                        array(
                            'id' => 'preloader-color',
                            'type' => 'color',
                            'title' => esc_html__('Preload color icon', 'bonfire'),
                            'validate' => 'color',
                            'default' => '', 
                            'required' => array(
                                    array('preload', 'equals', array(
                                    'enable'
                                )),
                            ),
                        ), 
                    )
                ),
                array(
                    'icon' => 'el-icon-css',
                    'icon_class' => 'icon',
                    'title' => esc_html__('Skin', 'bonfire'),
                ),
                array(
                    'icon_class' => 'icon',
                    'subsection' => true,
                    'title' => esc_html__('General', 'bonfire'),
                    'fields' => array(
                        array(
                            'id' => 'general-bg',
                            'type' => 'background',
                            'title' => esc_html__('General Background', 'bonfire'),
                            'default' => array(
                                'background-color' => '#fff',
                                'background-image' => '',
                                'background-size' => 'inherit',
                                'background-repeat' => 'no-repeat',
                                'background-position' => 'center center',
                                'background-attachment' => 'inherit'
                            ),
                            'output' => array('#main','body','#error-page'),
                        ),
                        array(
                            'id' => 'general-font',
                            'type' => 'typography',
                            'title' => esc_html__('General Font', 'bonfire'),
                            'google' => true,
                            'subsets' => false,
                            'font-style' => false,
                            'text-align' => false,
                            'default' => array(
                                'color' => "#696969",
                                'google' => true,
                                'font-weight' => '400',
                                'font-family' => 'Fira Sans',
                                'font-size' => '14px',
                                'line-height' => '24px'
                            ),
                            'output' => array('body','#error-page'),
                        ),
                        array(
                            'id' => 'primary-color',
                            'type' => 'color',
                            'title' => esc_html__('Primary color', 'bonfire'),
                            'default' => '#92c5d9',
                            'validate' => 'color',
                            'transparent' => false
                        ),
                        array(
                            'id' => 'highlight-color',
                            'type' => 'color',
                            'title' => esc_html__('Highlight color', 'bonfire'),
                            'default' => '#000000',
                            'validate' => 'color',
                            'transparent' => false
                        ),                        
                    )
                ),
                array(
                    'icon_class' => 'icon',
                    'subsection' => true,
                    'title' => esc_html__('Breadcrumbs', 'bonfire'),
                    'fields' => array(
                        array(
                            'id' => 'breadcrumbs_style',
                            'type' => 'button_set',
                            'title' => esc_html__('Breadcrumbs Layout', 'bonfire'),
                            'options' => apr_get_breadcrumbs_type(),
                            'default' => 'type-1'
                        ),
                         array(

                            'id' => 'breadcrumbs-bg',
                            'type' => 'background',
                            'title' => esc_html__('Background', 'bonfire'),
                            'background-color' => true, 
                            'default' => array(
                                'background-image' => get_template_directory_uri() . '/images/bg-breadcrumb.jpg',
                                'background-size' => 'cover',
                                'background-repeat' => 'no-repeat',
                                'background-position' => 'center center',
                                'background-attachment' => 'inherit',
                                'background-color' => 'none'
                            ),
                            'required' => array('breadcrumbs_style', 'equals', array(
                                    'type-1'
                            )),
                            'output'    => array('.side-breadcrumb.use_bg_image'
                            ),                                                               
                        ),
                         array(

                            'id' => 'breadcrumbs2-bg',
                            'type' => 'background',
                            'title' => esc_html__('Background', 'bonfire'),
                            'background-color' => true, 
                            'default' => array(
                                'background-image' => 'none',
                                'background-size' => 'cover',
                                'background-repeat' => 'no-repeat',
                                'background-position' => 'center center',
                                'background-attachment' => 'inherit',
                                'background-color' => '#f5f5f5',
                            ),
                            'required' => array('breadcrumbs_style', 'equals', array(
                                    'type-2'
                            )),
                            'output'    => array('.side-breadcrumb.type-2.use_bg_image'
                            ),                                                               
                        ), 
                        array(

                            'id' => 'breadcrumbs3-bg',
                            'type' => 'background',
                            'title' => esc_html__('Background', 'bonfire'),
                            'background-color' => true, 
                            'default' => array(
                                'background-image' => get_template_directory_uri() . '/images/bg-breadcrumb2.jpg',
                                'background-size' => 'cover',
                                'background-repeat' => 'no-repeat',
                                'background-position' => 'center center',
                                'background-attachment' => 'inherit',
                                'background-color' => 'none'
                            ),
                            'required' => array('breadcrumbs_style', 'equals', array(
                                    'type-3'
                            )),
                            'output'    => array('.side-breadcrumb.type-3.use_bg_image'),                                                               
                        ),
                        array(
                            'id' => 'breadcrumbs-overlay-color',
                            'type' => 'color',
                            'title' => esc_html__('Background Overlay Color', 'bonfire'),
                            'validate' => 'color',
                            'default' => 'transparent',                                                           
                        ), 
						array(
                            'id' => 'breadcrumbs_align',
                            'type' => 'button_set',
                            'title' => esc_html__('Breadcrumbs Align', 'bonfire'),
                            'options' => apr_get_align(),
                            'default' => 'center'
                        ),
						array(
                            'id'             => 'breadcrumbs_padding',
                            'type'           => 'spacing',
                            'mode'           => 'padding',
                            'units'          => array('px'),
                            'units_extended' => 'false',
                            'title'          => esc_html__('Set padding for breadcrumb in desktop', 'bonfire'),
                            'subtitle'       => esc_html__('Allow users to ajust breadcrumb spacing', 'bonfire'),                            
                        ),
						array(
                            'id' => 'title-breadcrumbs-font',
                            'type' => 'typography',
                            'title' => esc_html__('Title Page', 'bonfire'),
                            'google' => true,
                            'subsets' => false,
                            'font-style' => false,
                            'text-align' => false,
                            'font-weight' => true,
                            'line-height' => false,
                            'default' => array(
                                'color' => "#fff",
                                'google' => true,
                                'font-family' => 'Fira Sans',
                                'font-size' => '56px',
								'font-weight' => '700',
                            )
                        ),
						array(
							'id' => 'breadcrumbs-icon',
							'type' => 'text',
							'title' => esc_html__('Icon Home Breadcrumb', 'bonfire'),  
							'placeholder' => esc_html__('fa fa-home', 'bonfire'),
							'desc' => wp_kses(__('Add icon class you want here. You can find a lot of icons in these links <a target="_blank" href="http://fontawesome.io/icons/">Awesome icon</a> or <a target="_blank" href="https://linearicons.com/free">Linearicons </a>, and <a target="_blank" href="http://themes-pixeden.com/font-demos/7-stroke/">Pe stroke icon7 </a>','bonfire'),array(
									'a' => array(
										'href'=>array(),
										'target' => array(),
										),
								))                         
						),
						array(
                            'id' => 'link-breadcrumbs-font',
                            'type' => 'typography',
                            'title' => esc_html__('Link Breadcrumb Option', 'bonfire'),
                            'google' => true,
                            'subsets' => false,
                            'font-style' => false,
                            'text-align' => false,
                            'font-weight' => true,
                            'line-height' => false,
                            'default' => array(
                                'color' => "#fff",
                                'google' => true,
                                'font-family' => 'Fira Sans',
                                'font-size' => '14px',
                            )
                        ),  
					)
                ),
                array(
                    'icon_class' => 'icon',
                    'subsection' => true,
                    'title' => esc_html__('Typography', 'bonfire'),
                    'fields' => array(
                        array(
                            'id' => 'h1-font',
                            'type' => 'typography',
                            'title' => esc_html__('H1 Font', 'bonfire'),
                            'google' => true,
                            'subsets' => false,
                            'font-style' => false,
                            'text-align' => false,
                            'font-weight' => false,
                            'line-height' => false,
                            'default' => array(
                                'color' => "#333",
                                'google' => true,
                                'font-family' => 'Fira Sans',
                                'font-size' => '56px',
                            ),
                            'output' => array('h1'),
                        ),
                        array(
                            'id' => 'h2-font',
                            'type' => 'typography',
                            'title' => esc_html__('H2 Font', 'bonfire'),
                            'google' => true,
                            'subsets' => false,
                            'font-style' => false,
                            'text-align' => false,
                            'font-weight' => false,
                            'line-height' => false,
                            'default' => array(
                                'color' => "#333",
                                'google' => true,
                                'font-family' => 'Fira Sans',
                                'font-size' => '48px',
                            ),
                            'output' => array('h2'),
                        ),
                        array(
                            'id' => 'h3-font',
                            'type' => 'typography',
                            'title' => esc_html__('H3 Font', 'bonfire'),
                            'google' => true,
                            'subsets' => false,
                            'font-style' => false,
                            'text-align' => false,
                            'font-weight' => false,
                            'line-height' => false,
                            'default' => array(
                                'color' => "#333",
                                'google' => true,
                                'font-family' => 'Fira Sans',
                                'font-size' => '24px',
                            ),
                            'output' => array('h3'),
                        ),
                        array(
                            'id' => 'h4-font',
                            'type' => 'typography',
                            'title' => esc_html__('H4 Font', 'bonfire'),
                            'google' => true,
                            'subsets' => false,
                            'font-style' => false,
                            'text-align' => false,
                            'font-weight' => false,
                            'line-height' => false,
                            'default' => array(
                                'color' => "#333",
                                'google' => true,
                                'font-family' => 'Fira Sans',
                                'font-size' => '18px',
                            ),
                            'output' => array('h4'),                            
                        ),
                        array(
                            'id' => 'h5-font',
                            'type' => 'typography',
                            'title' => esc_html__('H5 Font', 'bonfire'),
                            'google' => true,
                            'subsets' => false,
                            'font-style' => false,
                            'text-align' => false,
                            'font-weight' => false,
                            'line-height' => false,
                            'default' => array(
                                'color' => "#333",
                                'google' => true,
                                'font-family' => 'Fira Sans',
                                'font-size' => '16px',
                            ),
                            'output' => array('h5'),
                        ),
                        array(
                            'id' => 'h6-font',
                            'type' => 'typography',
                            'title' => esc_html__('H6 Font', 'bonfire'),
                            'google' => true,
                            'subsets' => false,
                            'font-style' => false,
                            'text-align' => false,
                            'font-weight' => false,
                            'line-height' => false,
                            'default' => array(
                                'color' => "#333",
                                'google' => true,
                                'font-family' => 'Fira Sans',
                                'font-size' => '14px',
                            ),
                            'output' => array('h6'),
                        ),
                        array(
                            'id' => 'other-font',
                            'type' => 'typography',
                            'title' => esc_html__('Button and some title font', 'bonfire'),
                            'google' => true,
                            'subsets' => false,
                            'font-style' => false,
                            'text-align' => false,
                            'font-weight' => false,
                            'line-height' => false,
                            'color' => false,
                            'font-size' => false,
                            'default' => array(
                                'google' => true,
                                'font-family' => 'Cormorant Garamond',
                            ),
                            'output'=> array('.product-tab .nav-tabs > li a','.btn.btn-bg',
                                '.blog-item .post_link','.blog-grid-3 .post-name a','.blog-loadmore','.blog-slogan',
                                '.quote_section blockquote','.sticky-post-2 .post-name a',
                                '.blog-cat-content .blog-cate .count-post > p',
                                '.body-social a', '.title-port-service span',
                                '.box-port-service .aio-icon-component .aio-icon-box .aio-icon-header h3.aio-icon-title',
                                '.block-slider','.banner-text h2','.banner-desc-jewelry span','.banner-desc-jewelry h2','.tt-tes-jewelry','.box-list-banner .wpb_single_image .wpb_singleimage_heading','.block-about h2',
                                '.block-about .desc span','.product-category .title-cate h2',
                                '.product-category .count-post p','.product-category .btn-view-all',
                                '.tt-list span','.info .price span, #yith-quick-view-content .price span','.product_list_widget .price span'),
                        ),                        
                    )
                ),
                array(
                    'icon_class' => 'icon',
                    'subsection' => true,
                    'title' => esc_html__('Custom', 'bonfire'),
                    'fields' => array(
                        array(
                            'id' => 'custom-css-code',
                            'type' => 'ace_editor',
                            'title' => esc_html__('CSS', 'bonfire'),
                            'subtitle' => esc_html__('Enter CSS code here.', 'bonfire'),
                            'mode' => 'css',
                            'theme' => 'monokai',
                            'default' => ""
                        ),
                    )
                ),
                $this->apr_add_header_section_options(),
                array(
                    'icon_class' => 'el-icon-edit',
                    'subsection' => true,
                    'title' => esc_html__('Side Header Information', 'bonfire'),
                    'fields' => array(
                         array(
                            'id' => 'header-info',
                            'type' => 'switch',
                            'title' => esc_html__('Enable Side Header Information','bonfire'),                        
                            'default' => false,    
                        ),  
                        array(
                            'id' => 'header-info-icon',
                            'type' => 'text',
                            'title' => esc_html__('Icon Information', 'bonfire'),   
                            'default' => 'ion-ios-settings',
                            'placeholder' => esc_html__('ion-ios-settings', 'bonfire'),
                            'required' => array('header-info', 'equals', array(
                                true
                            )), 
                            'desc' => wp_kses(__('Add icon class you want here. You can find a lot of icons in these links <a target="_blank" href="http://fontawesome.io/icons/">Awesome icon</a> or <a target="_blank" href="https://linearicons.com/free">Linearicons </a>, <a target="_blank" href="http://themes-pixeden.com/font-demos/7-stroke/">Pe stroke icon7 </a> and <a target="_blank" href="https://www.dropbox.com/s/oy8lsb7u4eli7rt/bonfire_font.png?dl=0">Bonfire icon list </a>','bonfire'),array(
                                'a' => array(
                                    'href'=>array(),
                                    'target' => array(),
                                    ),
                            ))                            
                        ),
                        array(
                            'id' => 'header-slogan',
                            'type' => 'textarea',
                            'title' => esc_html__('Slogan', 'bonfire'),                        
                            'default' => 'Lorem ipsum dolor sit amet gravida nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auci. Proin gravida nibh vel veliau ctor aliquenean.',
                            'required' => array('header-info', 'equals', array(
                                true
                            )),  
                        ),
                        array(
                            'id' => 'side-twitter',
                            'type' => 'switch',
                            'title' => esc_html__('Show Twitter', 'bonfire'),
                            'default' => true,
                            'required' => array('header-info', 'equals', true),
                        ),
                        array(
                            'id' => 'side-contact',
                            'type' => 'switch',
                            'title' => esc_html__('Show Contact Form', 'bonfire'),
                            'default' => false,
                            'required' => array('header-info', 'equals', true),
                        ),
                        array(
                            'id' => 'form_contact',
                            'type' => 'textarea',
                            'title' => esc_html__('Contact form shortcode', 'bonfire'),
                            'default' => '',
                            'required' => array('side-contact', 'equals', true),
                            'desc' => esc_html__('Get contact form shortcode in Contact > Contact Forms','bonfire'),                        
                        ),
                        array(
                            'id' => 'side-instagram',
                            'type' => 'switch',
                            'title' => esc_html__('Show Instagram', 'bonfire'),
                            'default' => false,
                            'required' => array('header-info', 'equals', true),
                        ),
                        array(
                            'id' => "iframe-instagram",
                            'type' => 'textarea',
                            'required' => array('side-instagram', 'equals', true),
                            'title' => esc_html__('Iframe Instagram', 'bonfire'),
                            'desc' => esc_html__('Get Iframe In Website http://instaembedder.com/ or http://widgets.websta.me/', 'bonfire')
                        ),
                        array(
                            'id' => 'header-contact',
                            'type' => 'switch',
                            'title' => esc_html__('Show Contact Us', 'bonfire'),                        
                            'default' => true,
                        ), 
                        array(
                            'id' => 'header-callto',
                            'type' => 'text',
                            'title' => esc_html__('Callto', 'bonfire'),                        
                            'default' => '+84437955813',
                            'required' => array('header-contact', 'equals', array(
                                true
                            )),
                        ), 
                        array(
                            'id' => 'header-mailto',
                            'type' => 'text',
                            'title' => esc_html__('Mailto', 'bonfire'),                        
                            'default' => 'arrowpress@arrowhitech.com',
                            'required' => array('header-contact', 'equals', array(
                                true
                            )),
                        ),                        
                    )
                ),
                array(
                    'icon_class' => 'el-icon-edit',
                    'subsection' => true,
                    'title' => esc_html__('Header Styling', 'bonfire'),
                    'fields' => array(
                        array(
                            'id'       => 'logo_width',
                            'type'     => 'dimensions',
                            'units'    => array('em','px','%'),
                            'title'    => esc_html__('Set logo image width and height', 'bonfire'),
                            'subtitle' => esc_html__('Allow users to set width and height for header logo image', 'bonfire'),
                            'height'   => true,
                        ), 
                        array(
                            'id'       => 'logo_mobile',
                            'type'     => 'dimensions',
                            'units'    => array('em','px','%'),
                            'title'    => esc_html__('[Mobile] Set logo image width and height in mobile menu', 'bonfire'),
                            'height'   => true,
                        ),    
                        array(
                            'id'       => 'logo_sidebar',
                            'type'     => 'dimensions',
                            'units'    => array('em','px','%'),
                            'title'    => esc_html__('[Side Information] Set logo image width and height', 'bonfire'),
                            'height'   => true,
                        ),                          
                        array(
                            'id'             => 'logo_padding',
                            'type'           => 'spacing',
                            'mode'           => 'margin',
                            'units'          => array('px'),
                            'units_extended' => 'false',
                            'title'          => esc_html__('Set padding for header logo in desktop', 'bonfire'),
                            'subtitle'       => esc_html__('Allow users to ajust logo spacing', 'bonfire'),                            
                        ),                                                
                        array(
                            'id'             => 'menu_spacing',
                            'type'           => 'spacing',
                            'mode'           => 'margin',
                            'units'          => array('px'),
                            'units_extended' => 'false',
                            'title'          => esc_html__('Set padding for menu items', 'bonfire'),
                            'subtitle'       => esc_html__('Allow users to ajust menu item spacing', 'bonfire'),                              
                        ),                         
                        array(
                            'id' => 'header-style',
                            'type' => 'select',
                            'title' => esc_html__('Select header for styling', 'bonfire'),
                            'options' => apr_header_types(),
                            'default' => '1',
                        ),     
                        //header 1                                                   
                        array(
                            'id' => 'header1-bg',
                            'type' => 'color',
                            'title' => esc_html__('Header background color', 'bonfire'),
                            'validate' => 'color',
                            'default' => '#333',
                            'required' => array('header-style', 'equals', array(
                                    '1'
                                )),                                
                        ),
						array(
                            'id' => 'header-bg-image',
                            'type' => 'background',
                            'title' => esc_html__('Background Image', 'bonfire'),
                            'background-color' => false, 
                            'default' => array(
                                'background-image' => '',
                                'background-size' => 'cover',
                                'background-repeat' => 'no-repeat',
                                'background-position' => 'center center',
                                'background-attachment' => 'fixed',
                            ),
                            'output'    => array('header.site-header', 
                                '.fixed-header header.site-header.is-sticky',
                            ),                                                               
                        ),    
						array(
                            'id' => 'header-overlay-color',
                            'type' => 'color',
                            'title' => esc_html__('Header Background Overlay Color', 'bonfire'),
                            'validate' => 'color',
                            'default' => 'transparent',                                                           
                        ),
						array(
                            'id' => 'header-opacity',
                            'type' => 'text',
							'placeholder' => esc_html__('0.6', 'bonfire'),
                            'title' => esc_html__('Header Background Opacity', 'bonfire'),
							'default' => '0.6',
                        ),
                        array(
                            'id' => 'header1-color',
                            'type' => 'color',
                            'title' => esc_html__('Header Color', 'bonfire'),
                            'validate' => 'color',
							'default' => '#ffffff',
                            'transparent' => false, 
                            'required' => array('header-style', 'equals', array(
                                    '1'
                                )),                                                     
                        ),  
						array(
                            'id' => 'header1-bg-hover',
                            'type' => 'color',
                            'title' => esc_html__('Header background color hover submenu', 'bonfire'),
                            'validate' => 'color',
                            'default' => '#282828',
                            'required' => array('header-style', 'equals', array(
                                    '1'
                                )),                                
                        ), 
                        array(
                            'id' => 'header1-border-color',
                            'type' => 'color',
                            'title' => esc_html__('Header Submenu Border Color', 'bonfire'),
                            'default' => '#555',
                            'validate' => 'color',
                            'transparent' => true,
                            'required' => array('header-style', 'equals', array(
                                    '1'             
                                )),                            
                        ),  
                    // Header 2
                         array(
                            'id' => 'header2-bg',
                            'type' => 'color',
                            'title' => esc_html__('Header background color', 'bonfire'),
                            'validate' => 'color',
                            'default' => '#333',
                            'required' => array('header-style', 'equals', array(
                                    '2'
                                )),                                
                        ),                         
                        array(
                            'id' => 'header2-color',
                            'type' => 'color',
                            'title' => esc_html__('Header Color', 'bonfire'),
                            'validate' => 'color',
                            'default' => '#ffffff',
                            'transparent' => false, 
                            'required' => array('header-style', 'equals', array(
                                    '2'
                                )),                                                     
                        ),
                          array(
                            'id' => 'header2-icon-color',
                            'type' => 'color',
                            'title' => esc_html__('Header Icon Color', 'bonfire'),
                            'validate' => 'color',
                            'default' => '#696969',
                            'transparent' => false, 
                            'required' => array('header-style', 'equals', array(
                                    '2'
                                )),                                                     
                        ),    
                        array(
                            'id' => 'header2-bg-hover',
                            'type' => 'color',
                            'title' => esc_html__('Header background color hover submenu', 'bonfire'),
                            'validate' => 'color',
                            'default' => '#282828',
                            'required' => array('header-style', 'equals', array(
                                    '2'
                                )),                                
                        ), 
                        array(
                            'id' => 'header2-border-color',
                            'type' => 'color',
                            'title' => esc_html__('Header Submenu Border Color', 'bonfire'),
                            'default' => '#555',
                            'validate' => 'color',
                            'transparent' => true,
                            'required' => array('header-style', 'equals', array(
                                    '2'             
                                )),                            
                        ),
                    //Header 3 
                        array(
                            'id'       => 'logo_wrapper_size',
                            'type'     => 'dimensions',
                            'units'    => array('em','px','%'),
                            'title'    => esc_html__('[Desktop] Set logo image wrapper width and height for header3', 'bonfire'),
                            'height'   => true,
                            'required' => array('header-style', 'equals', array(
                                    '3'
                                )),                              
                        ),                        
                        array(
                            'id' => 'header3-bg',
                            'type' => 'color',
                            'title' => esc_html__('Header Background Color', 'bonfire'),
                            'default' => '#fff',
                            'validate' => 'color',
                            'transparent' => true,
                            'required' => array('header-style', 'equals', array(
                                    '3'
                                )),                                
                        ),   
						array(
                            'id' => 'header3-color',
                            'type' => 'color',
                            'title' => esc_html__('Header Menu Color', 'bonfire'),
                            'default' => '#5c6771',
                            'validate' => 'color',
                            'transparent' => true,
                            'required' => array('header-style', 'equals', array(
                                    '3'                      
                                )),                            
                        ), 
                        array(
                            'id' => 'header3-icon-color',
                            'type' => 'color',
                            'title' => esc_html__('Header Icon Color', 'bonfire'),
                            'default' => '#333',
                            'validate' => 'color',
                            'transparent' => true,
                            'required' => array('header-style', 'equals', array(
                                    '3'                      
                                )),                            
                        ), 
                        array(
                            'id' => 'header3-bg-hover',
                            'type' => 'color',
                            'title' => esc_html__('Submenu background color on hover ', 'bonfire'),
                            'validate' => 'color',
                            'default' => '#f7f6f6',
                            'required' => array('header-style', 'equals', array(
                                    '3'
                                )),                                
                        ), 
                        array(
                            'id' => 'header3-border-color',
                            'type' => 'color',
                            'title' => esc_html__('Submenu Border Color', 'bonfire'),
                            'default' => '#f0efef',
                            'validate' => 'color',
                            'transparent' => true,
                            'required' => array('header-style', 'equals', array(
                                    '3'               
                                )),                            
                        ),       
                        array(
                            'id' => 'header3-logo-bg',
                            'type' => 'color',
                            'title' => esc_html__('Header logo background color', 'bonfire'),
                            'validate' => 'color',
                            'output' => array('background-color'=> '.header-v3 .header-wrapper .header-logo'),  
                            'required' => array('header-style', 'equals', array(
                                    '3'
                                )),                                                         
                        ), 
                    // Header 4
                         array(
                            'id' => 'header4-bg',
                            'type' => 'color',
                            'title' => esc_html__('Header background color', 'bonfire'),
                            'validate' => 'color',
                            'default' => '#fff',
                            'required' => array('header-style', 'equals', array(
                                    '4'
                                )),                                
                        ),                         
                        array(
                            'id' => 'header4-color',
                            'type' => 'color',
                            'title' => esc_html__('Header Color', 'bonfire'),
                            'validate' => 'color',
                            'default' => '#5c6771',
                            'transparent' => false, 
                            'required' => array('header-style', 'equals', array(
                                    '4'
                                )),                                                     
                        ),  
                         array(
                            'id' => 'header4-icon-color',
                            'type' => 'color',
                            'title' => esc_html__('Header Icon Color', 'bonfire'),
                            'validate' => 'color',
                            'default' => '#333',
                            'transparent' => false, 
                            'required' => array('header-style', 'equals', array(
                                    '4'
                                )),                                                     
                        ),
                        array(
                            'id' => 'header4-bg-hover',
                            'type' => 'color',
                            'title' => esc_html__('Header background color hover submenu', 'bonfire'),
                            'validate' => 'color',
                            'default' => '#f7f6f6',
                            'required' => array('header-style', 'equals', array(
                                    '4'
                                )),                                
                        ), 
                        array(
                            'id' => 'header4-border-color',
                            'type' => 'color',
                            'title' => esc_html__('Header Submenu Border Color', 'bonfire'),
                            'default' => '#f0efef',
                            'validate' => 'color',
                            'transparent' => true,
                            'required' => array('header-style', 'equals', array(
                                    '4'             
                                )),                            
                        ),
                        //Header 5 
                        array(
                            'id' => 'header5-bg',
                            'type' => 'color',
                            'title' => esc_html__('Header Background Color', 'bonfire'),
                            'default' => '#fff',
                            'validate' => 'color',
                            'transparent' => true,
                            'required' => array('header-style', 'equals', array(
                                    '5'
                                )),                                
                        ),   
                        array(
                            'id' => 'header5-color',
                            'type' => 'color',
                            'title' => esc_html__('Header Menu Color', 'bonfire'),
                            'default' => '#5c6771',
                            'validate' => 'color',
                            'transparent' => true,
                            'required' => array('header-style', 'equals', array(
                                    '5'                      
                                )),                            
                        ), 
                        array(
                            'id' => 'header5-icon-color',
                            'type' => 'color',
                            'title' => esc_html__('Header Icon Color', 'bonfire'),
                            'default' => '#333',
                            'validate' => 'color',
                            'transparent' => true,
                            'required' => array('header-style', 'equals', array(
                                    '5'                      
                                )),                            
                        ), 
                        array(
                            'id' => 'header5-bg-hover',
                            'type' => 'color',
                            'title' => esc_html__('Submenu background color on hover ', 'bonfire'),
                            'validate' => 'color',
                            'default' => '#f7f6f6',
                            'required' => array('header-style', 'equals', array(
                                    '5'
                                )),                                
                        ), 
                        array(
                            'id' => 'header5-border-color',
                            'type' => 'color',
                            'title' => esc_html__('Submenu Border Color', 'bonfire'),
                            'default' => '#f0efef',
                            'validate' => 'color',
                            'transparent' => true,
                            'required' => array('header-style', 'equals', array(
                                    '5'               
                                )),                            
                        ),       
                        array(
                            'id' => 'header5-button-bg',
                            'type' => 'color',
                            'title' => esc_html__('Header button background color', 'bonfire'),
                            'validate' => 'color',
                            'output' => array('background-color'=> '.header-v5 .header-left .header-info'),  
                            'required' => array('header-style', 'equals', array(
                                    '5'
                                )),                                                         
                        ),
                        //header 1                          
                        array(
                            'id' => 'header6-bg',
                            'type' => 'color',
                            'title' => esc_html__('Header background color', 'bonfire'),
                            'validate' => 'color',
                            'default' => '#333',
                            'required' => array('header-style', 'equals', array(
                                    '6'
                                )),                                
                        ),                         
                        array(
                            'id' => 'header6-color',
                            'type' => 'color',
                            'title' => esc_html__('Header Color', 'bonfire'),
                            'validate' => 'color',
                            'default' => '#ffffff',
                            'transparent' => false, 
                            'required' => array('header-style', 'equals', array(
                                    '6'
                                )),                                                     
                        ),  
                        array(
                            'id' => 'header6-bg-hover',
                            'type' => 'color',
                            'title' => esc_html__('Header background color hover submenu', 'bonfire'),
                            'validate' => 'color',
                            'default' => '#282828',
                            'required' => array('header-style', 'equals', array(
                                    '6'
                                )),                                
                        ), 
                        array(
                            'id' => 'header6-border-color',
                            'type' => 'color',
                            'title' => esc_html__('Header Submenu Border Color', 'bonfire'),
                            'default' => '#555',
                            'validate' => 'color',
                            'transparent' => true,
                            'required' => array('header-style', 'equals', array(
                                    '6'             
                                )),                            
                        ),
                                                                                                               
                    )                  
                ),                
                array(
                    'icon' => 'el-icon-edit',
                    'icon_class' => 'icon',
                    'title' => esc_html__('Footer', 'bonfire'),
                    'fields' => array(
                        array(
                            'id' => 'footer-type',
                            'type' => 'image_select',
                            'title' => esc_html__('Footer Type', 'bonfire'),
                            'options' => $this->apr_footer_types(),
                            'subtitle' => esc_html__('Each page will have option for select footer type. Footer selection in each page will have higher priority than this general selection.','bonfire'),
                            'default' => '1'
                        ),
                        array(
                            'id' => 'footer-position',
                            'type' => 'switch',
                            'title' => esc_html__('Footer Fixed', 'bonfire'),                        
                            'default' => false,
                        ),
                        array(
                            'id' => 'logo_footer',
                            'type' => 'media',
                            'url' => true,
                            'readonly' => false,
                            'title' => esc_html__('Footer logo', 'bonfire'), 
                            'default' => array(
                                'url' => get_template_directory_uri() . '/images/logo_footer.png',
                            )
                        ),  
                        array(
                            'id' => "footer-copyright",
                            'type' => 'textarea',
                            'title' => esc_html__('Copyright', 'bonfire'),
                            'default' => wp_kses( __(' <p>14 L.E Goulburn St, Sydney 2000NSW  -  <a href="tel:08819906886">(088) 1990 6886</a></p> <p>Copyright 2017 Bonfire </p>', 'bonfire'), 
                                array(
                                'a' => array(
                                    'href' => array(),
                                    'title' => array(),
                                    'target' => array(),
                                ),
                                'p' => array('class' => array()),
                                'br' => array(),
                                'i' => array(
                                    'class' => array(),
                                    'aria-hidden' => array(),
                                ),
                            )),  
                            'required' => array('footer-type', 'equals', array(
                                    '1','2'
                                )),                        
                        ),
                        array(
                            'id' => "footer3-copyright",
                            'type' => 'textarea',
                            'title' => esc_html__('Copyright', 'bonfire'),
                            'default' => wp_kses( __(' <p>Copyright 2017 Bonfire. Powered by ArrowHitech. </p>', 'bonfire'), 
                                array(
                                'a' => array(
                                    'href' => array(),
                                    'title' => array(),
                                    'target' => array(),
                                ),
                                'p' => array('class' => array()),
                                'br' => array(),
                                'i' => array(
                                    'class' => array(),
                                    'aria-hidden' => array(),
                                ),
                            )), 
                            'required' => array('footer-type', 'equals', array(
                                    '3'
                                )),                            
                        ),
                        array(
                            'id' => "footer3-info",
                            'type' => 'textarea',
                            'title' => esc_html__('Description  footer', 'bonfire'),
                            'default' => wp_kses( __(' <p> We would love to talk to you about our unique approach and how we might be able to help your brand.</p>', 'bonfire'), 
                                array(
                                'a' => array(
                                    'href' => array(),
                                    'title' => array(),
                                    'target' => array(),
                                ),
                                'p' => array('class' => array()),
                                'br' => array(),
                                'i' => array(
                                    'class' => array(),
                                    'aria-hidden' => array(),
                                ),
                            )), 
                            'required' => array('footer-type', 'equals', array(
                                    '3'
                                )),                            
                        ),
                        
                    )
                ),
                array(
                    'icon_class' => 'el-icon-edit',
                    'subsection' => true,
                    'title' => esc_html__('Social link', 'bonfire'),
                    'fields' => array(
                        array(
                            'id' => 'show-social',
                            'type' => 'switch',
                            'title' => esc_html__('Show footer social', 'bonfire'),                        
                            'default' => false,
                        ),                                               
                        array(
                            'id' => 'social-facebook',
                            'type' => 'text',
                            'title' => esc_html__('Facebook', 'bonfire'),
                            'placeholder' => esc_html__('https://facebook.com/arrowpress', 'bonfire')
                        ),                        
                        array(
                            'id' => 'social-twitter',
                            'type' => 'text',
                            'title' => esc_html__('Twitter', 'bonfire'),
                            'placeholder' => esc_html__('https://twitter.com/arrowpress1', 'bonfire'), 
                        ),
                        array(
                            'id' => 'social-youtube',
                            'type' => 'text',
                            'title' => esc_html__('Youtube', 'bonfire'),                            
                            'placeholder' => esc_html__('http://', 'bonfire'), 
                        ),                        
                        array(
                            'id' => 'social-skype',
                            'type' => 'text',
                            'title' => esc_html__('Skype', 'bonfire'),                           
                            'placeholder' => esc_html__('http://', 'bonfire'), 
                        ),                        
                        array(
                            'id' => 'social-google',
                            'type' => 'text',
                            'title' => esc_html__('Google', 'bonfire'),
                            'placeholder' => esc_html__('http://', 'bonfire')
                        ), 
                        array(
                            'id' => 'social-instagram',
                            'type' => 'text',
                            'title' => esc_html__('Instagram', 'bonfire'),
                            'placeholder' => esc_html__('https://www.instagram.com/aprbaber/', 'bonfire')
                        ),       
                        array(
                            'id' => 'social-pinterest',
                            'type' => 'text',
                            'title' => esc_html__('Pinterest', 'bonfire'),
                            'placeholder' => esc_html__('http://', 'bonfire')
                        ),
                        array(
                            'id' => 'social-dribbble',
                            'type' => 'text',
                            'title' => esc_html__('Dribbble', 'bonfire'),
                            'placeholder' => esc_html__('http://', 'bonfire')
                        ),
                        array(
                            'id' => 'social-linkedin',
                            'type' => 'text',
                            'title' => esc_html__('Linkedin', 'bonfire'),
                            'placeholder' => esc_html__('http://', 'bonfire')
                        ),                   
                        array(
                            'id' => 'social-behance',
                            'type' => 'text',
                            'title' => esc_html__('Behance', 'bonfire'),
                            'placeholder' => esc_html__('http://', 'bonfire')
                        ),                        
                    ),
                ),
                array(
                    'icon_class' => 'el-icon-edit',
                    'subsection' => true,
                    'title' => esc_html__('Footer Styling', 'bonfire'),
                    'fields' => array(
                        array(
                            'id' => 'footer-style',
                            'type' => 'select',
                            'title' => esc_html__('Select footer for styling', 'bonfire'),
                            'options' => apr_footer_types(),
                            'default' => '1',
                        ),
                        array(
                            'id' => 'bg_img_footer',
                            'type' => 'background',
                            'title' => esc_html__('Background footer', 'bonfire'),
                            'background-color' => true, 
                            'default' => array(
                                'background-color' =>'#333',
                                'background-image' => '',
                                'background-size' => 'cover',
                                'background-repeat' => 'no-repeat',
                                'background-position' => 'center center',
                                'background-attachment' => 'fixed'
                            ),
                            'required' => array('footer-style', 'equals', array(
                                    '1','2','3'
                                )),                            
                            'output'    => array(
                                'background-image' =>'.footer-v1','.footer-v2','.footer-v3 .footer_wrap',
                                'background-size' => '.footer-v1','.footer-v2','.footer-v3 .footer_wrap',
                                'background-repeat' => '.footer-v1','.footer-v2','.footer-v3 .footer_wrap',
                                'background-position' => '.footer-v1','.footer-v2','.footer-v3 .footer_wrap',
                                'background-attachment' => '.footer-v1','.footer-v2','.footer-v3 .footer_wrap',
                                'background-color' =>'.footer-v1','.footer-v2','.footer-v3 .footer_wrap',
                            ),                                                              
                        ), 
                        array(
                            'id' => 'footer-t-before-color',
                            'type' => 'color',
                            'title' => esc_html__('Before title color', 'bonfire'),
                            'required' => array('footer-style', 'equals', array(
                                    '1'
                                )),
                            'validate' => 'color',
                            'transparent' =>false,
                            'output' => array('.footer-v1 .footer-title .before_title'),
                        ),                                                                                                                      
                        array(
                            'id' => 'footer-t-color',
                            'type' => 'color',
                            'title' => esc_html__('Title color', 'bonfire'),
                            'required' => array('footer-style', 'equals', array(
                                    '1','3'
                                )),
                            'default' => '#f8f7f7',
                            'validate' => 'color',
                            'transparent' =>false,
                            'output' => array('.footer-v1 .footer-title'),
                        ), 
                        array(
                            'id' => 'footer-color',
                            'type' => 'color',
                            'title' => esc_html__('Footer text color', 'bonfire'),
                            'required' => array('footer-style', 'equals', array(
                                    '1','2','3'
                                )),
                            'default' => '#ababab',
                            'validate' => 'color',
                            'transparent' =>false,
                            'output' => array('.footer-v1',
                                '.footer-v1 .footer-social li a, .footer-v1 a,
                                .list-info-footer li a','.footer-v2 .widget_mc4wp_form_widget .footer-title',
                                '.footer-v2 .widget_nav_menu ul li a,.footer-v2 .footer-social li a',
                                '.footer-v3 .footer-social li a', '.footer-v3 .bottom-footer','.footer-v1 .bottom-footer .copy-right','.footer-v1 .bottom-footer .copy-right a','.footer-v3 .list-info-footer li','.footer_info','.footer-v3 .hiden-label'),
                        ), 
                        array(
                            'id' => 'footer2-color',
                            'type' => 'color',
                            'title' => esc_html__('Footer text color', 'bonfire'),
                            'required' => array('footer-style', 'equals', array(
                                    '2'
                                )),
                            'default' => '#696969',
                            'validate' => 'color',
                            'transparent' =>false,
                            'output' => array('.footer-v2 .bottom-footer .copy-right','.footer-v2 .bottom-footer .copy-right a'),
                        ),     
                        array(
                            'id' => 'footer-twitter-icon',
                            'type' => 'color',
                            'title' => esc_html__('Twitter icon color', 'bonfire'),
                            'required' => array('footer-style', 'equals', array(
                                    '1',
                                )),
                            'validate' => 'color',
                            'transparent' =>false,
                            'output' => array('.footer-v1 .twitter-tweet i'),
                        ),                          
                        array(
                            'id'        => 'bottom-footer-border',
                            'type'      => 'color_rgba',
                            'title'     => esc_html__('Bottom footer border color', 'bonfire'),                       
                            'output'    => array('border-top-color' => '.footer-v1 .bottom-footer'),
                            'options'       => array(
                                'show_input'                => true,
                                'show_initial'              => true,
                                'show_alpha'                => true,
                                'show_palette'              => true,
                                'show_palette_only'         => false,
                                'show_selection_palette'    => true,
                                'max_palette_size'          => 10,
                                'allow_empty'               => true,
                                'clickout_fires_change'     => false,
                                'choose_text'               => 'Choose',
                                'cancel_text'               => 'Cancel',
                                'show_buttons'              => true,
                                'use_extended_classes'      => true,
                                'palette'                   => null,  // show default
                                'input_text'                => 'Select Color'
                            ), 
                            'required' => array('footer-style', 'equals', array(
                                    '1','2'
                                )),                                               
                        ),                                                                                                                                            
                    )
                ),                
                array(
                    'icon' => 'el-icon-th',
                    'icon_class' => 'icon',
                    'title' => esc_html__('Blog', 'bonfire'),
                    'fields' => array(
                        array(
                            'id' => '1',
                            'type' => 'info',
                            'desc' => esc_html__('Blog layout default', 'bonfire')
                        ),
                        array(
                            'id' => 'blog-title',
                            'type' => 'text',
                            'title' => esc_html__('Page Title', 'bonfire'),
                            'default' => 'Blog'
                        ),                        
                        array(
                            'id' => 'post-layout',
                            'type' => 'button_set',
                            'title' => esc_html__('Layout', 'bonfire'),
                            'options' => $page_layout,
                            'default' => 'fullwidth'
                        ),
                        array(
                            'id' => 'left-post-sidebar',
                            'type' => 'select',
                            'title' => esc_html__('Select Left Sidebar', 'bonfire'),
                            'data' => 'sidebars',
                            'default' => ''
                        ),
                        array(
                            'id' => 'right-post-sidebar',
                            'type' => 'select',
                            'title' => esc_html__('Select Right Sidebar', 'bonfire'),
                            'data' => 'sidebars',
                            'default' => ''
                        ),
                        array(
                            'id'=>'post-share',
                            'type' => 'button_set',
                            'title' => esc_html__('Post Share Links', 'bonfire'),
                            'multi' => true,
                            'options'=> array(
                                'facebook' => esc_html__('Facebook', 'bonfire'),    
                                'twitter' => esc_html__('Twitter', 'bonfire'),
                                'pin' => esc_html__('Pinterest', 'bonfire'),
                                'insta' => esc_html__('Instagram', 'bonfire'),
                            ), 
                            'default' => array('')
                        ),                                                                                                               
                    )
                ),
                array(
                    'icon_class' => 'icon',
                    'subsection' => true,
                    'title' => esc_html__('Blog Archive', 'bonfire'),
                    'fields' => array(
                        array(
                            'id' => 'post-layout-version',
                            'type' => 'button_set',
                            'title' => esc_html__('Blog Layout', 'bonfire'),
                            'options' => apr_page_blog_layouts(),
                            'default' => 'classic'
                        ),
                        array(
                            'id' => 'post-layout-columns',
                            'type' => 'button_set',
                            'title' => esc_html__('Blog Columns', 'bonfire'),
                            'options' => apr_page_blog_columns(),
                            'default' => '3',
                            'required' => array('post-layout-version', 'equals', array(
                                    'grid','masonry',
                                )),                            
                        ),
                        array(
                            'id' => 'blog-slogan',
                            'type' => 'textarea',
                            'title' => esc_html__('Blog Description', 'bonfire'),
                            'default' => wp_kses(__('We are a creative studio focused on <span>web design</span>. Inspiration is the one<br> word we love and we put it into our work everyday.','bonfire'),apr_allow_html()),                           
                        ),                        
                        array(
                            'id'       => 'post_per_page',
                            'type'     => 'spinner', 
                            'title'    => esc_html__('Post show per page', 'bonfire'),
                            'default'  => '9',
                            'min'      => '1',
                            'step'     => '1',
                            'max'      => '50',
                            'required' => array('post-layout-version', 'equals', array(
                                    'masonry',
                                )),                             
                        ),                                                
                        array(
                            'id' => 'post_pagination',
                            'type' => 'button_set',
                            'title' => esc_html__('Pagination type', 'bonfire'),
                            'options' => array(
                                '1' => esc_html__('Load more','bonfire'), 
                                '2' => esc_html__('Next/Prev','bonfire'),
                                '3' => esc_html__('Number','bonfire'),  
                             ),
                            'default' => '3'
                        ), 
                        array(
                            'id'=>'toolbar-post',
                            'type' => 'button_set',
                            'title' => esc_html__('Toolbar', 'bonfire'),
                            'multi' => true,
                            'options'=> array(
                                'count' => esc_html__('Count', 'bonfire'),    
                                'cat' => esc_html__('Categories', 'bonfire'),
                                'archive' => esc_html__('Archive', 'bonfire'),
                                'seach' => esc_html__('Search', 'bonfire'),
                            ),
                            'default' => array('count','cat','archive','seach'),                            
                        ),                        
                        array(
                            'id'=>'post-meta2',
                            'type' => 'button_set',
                            'title' => esc_html__('Post Meta', 'bonfire'),
                            'multi' => true,
                            'options'=> array(
                                'author' => esc_html__('Author', 'bonfire'),    
                                'comment' => esc_html__('Comment', 'bonfire'),
                                'date' => esc_html__('Date', 'bonfire'),
                                'like' => esc_html__('Like', 'bonfire'),
                                'cat' => esc_html__('Categories', 'bonfire'),
                                'tag' => esc_html__('Tags', 'bonfire'),
                                'view' => esc_html__('View', 'bonfire'),
                            ),
                            'default' => array('view','date','cat','tag'),                            
                        ),                                                                                        
                        array(
                            'id' => 'blog-text-share',
                            'type' => 'text',
                            'title' => esc_html__('Text display before share icons.', 'bonfire'),
                            'default' => esc_html__('Share this post', 'bonfire'),
                            'required' => array('post-layout-version', 'equals', array(
                                    'classic',
                            )),                             
                        ), 
                    )
                ),
                array(
                    'icon_class' => 'icon',
                    'subsection' => true,
                    'title' => esc_html__('Single Blog', 'bonfire'),
                    'fields' => array(
                        array(
                            'id' => 'single-post-layout-version',
                            'type' => 'button_set',
                            'title' => esc_html__('Single Blog Layout', 'bonfire'),
                            'options' => apr_page_single_blog_layouts(),
                            'default' => 'single-1'
                        ),
                        array(
                            'id'=>'post-meta-single',
                            'type' => 'button_set',
                            'title' => esc_html__('Post Meta in post detail page', 'bonfire'),
                            'multi' => true,
                            'options'=> array(
                                'author' => esc_html__('Author', 'bonfire'),    
                                'comment' => esc_html__('Comment', 'bonfire'),
                                'date' => esc_html__('Date', 'bonfire'),
                                'like' => esc_html__('Like', 'bonfire'),
                                'cat' => esc_html__('Categories', 'bonfire'),
                                'tag' => esc_html__('Tags', 'bonfire'),
                                'view' => esc_html__('View', 'bonfire'),
                            ),
                            'default' => array('view','date','cat','tag'),                            
                        ),
                    )
                ),
                array(
                    'icon' => 'el-icon-picture',
                    'icon_class' => 'icon',
                    'title' => esc_html__('Portfolio', 'bonfire'),
                    'fields' => array(
                        array(
                            'id' => '2',
                            'type' => 'info',
                            'desc' => esc_html__('Portfolio Archive Page', 'bonfire')
                        ),                                               
                        array(
                           'id' => 'section-start',
                           'type' => 'section',
                           'title' => esc_html__('Changing portfolio slug', 'bonfire'),
                           'indent' => true,                    
                        ),                        
                        array(
                            'id'        => 'gallery_slug',
                            'type'      => 'text',
                            'title'     => esc_html__('Custom Slug', 'bonfire'),
                            'subtitle'  => esc_html__('If you want your gallery post type to have a custom slug in the url, please enter it here.', 'bonfire'),
                            'desc'      => esc_html__('You will still have to refresh your permalinks after saving this! 
    This is done by going to Settings > Permalinks and clicking save.', 'bonfire'),
                            'validate'  => 'str_replace',
                            'str'       => array(
                                'search'        => ' ', 
                                'replacement'   => '-'
                            ),
                            'default'   => 'gallery',                    
                        ),  
                        array(
                            'id'        => 'gallery_cat_slug',
                            'type'      => 'text',
                            'title'     => esc_html__('Custom Slug for Portfolio category', 'bonfire'),
                            'subtitle'  => esc_html__('If you want your gallery category to have a custom slug in the url, please enter it here.', 'bonfire'),
                            'desc'      => esc_html__('You will still have to refresh your permalinks after saving this! 
    This is done by going to Settings > Permalinks and clicking save.', 'bonfire'),
                            'validate'  => 'str_replace',
                            'str'       => array(
                                'search'        => ' ', 
                                'replacement'   => '-'
                            ),
                            'default'   => 'gallery_cat',                    
                        ), 
                        array(
                            'id'     => 'section-end',
                            'type'   => 'section',
                            'indent' => false,                        
                        ),
                        array(
                            'id' => 'gallery_desc',
                            'type' => 'textarea',
                            'title' => esc_html__('Gallery Description', 'bonfire'),
                            'default' => esc_html__('It started with a simple idea: Create quality, well-designed products that I wanted myself.','bonfire'),                          
                        ),                           
                        array(
                            'id' => 'gallery_filter',
                            'type' => 'switch',
                            'title' => esc_html__('Show Filter', 'bonfire'),
                            'default' => true,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire')
                        ),                        
                        array(
                            'id' => '3',
                            'type' => 'info',
                            'desc' => esc_html__('The below options is also available in each Gallery Category. Please go to Gallery > Gallery Category and edit a category for more detail. The selections in each category will have higher priority than below general selections', 'bonfire')
                        ),                                                                                     
                        array(
                            'id' => 'gallery-layout',
                            'type' => 'button_set',
                            'title' => esc_html__('General Layout', 'bonfire'),
                            'options' => $page_layout,
                            'default' => 'fullwidth'
                        ),
                        array(
                            'id' => 'left-gallery-sidebar',
                            'type' => 'select',
                            'title' => esc_html__('Select Left Sidebar', 'bonfire'),
                            'data' => 'sidebars',
                            'default' => ''
                        ),
                        array(
                            'id' => 'right-gallery-sidebar',
                            'type' => 'select',
                            'title' => esc_html__('Select Right Sidebar', 'bonfire'),
                            'data' => 'sidebars',
                            'default' => ''
                        ),
                        array(
                            'id' => 'gallery-cols',
                            'type' => 'button_set',
                            'title' => esc_html__('Portfolio Columns', 'bonfire'),
                            'options' => apr_gallery_columns(),
                            'default' => '3',
                        ),
                        array(
                            'id' => 'gallery-space',
                            'type' => 'switch',
                            'title' => esc_html__('Remove space', 'bonfire'),
                            'default' => false,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire')
                        ), 
                        array(
                            'id' => 'gallery-style',
                            'type' => 'button_set',
                            'title' => esc_html__('Portfolio Style', 'bonfire'),
                            'options' => apr_gallery_style(),
                            'default' => 'style1',                
                        ), 
                        array(
                            'id' => 'gallery-style-version',
                            'type' => 'button_set',
                            'title' => esc_html__('Portfolio layouts', 'bonfire'),
                            'options' => apr_page_gallery_layouts(),
                            'default' => '1'
                        ),   
                        array(
                            'id' => 'gallery-masonry-version',
                            'type' => 'button_set',
                            'title' => esc_html__('Portfolio Masonry layouts', 'bonfire'),
                            'options' => apr_page_masonry_layouts(),
                            'default' => 'masonry1',
                            'required' => array('gallery-style-version', 'equals', array(
                                    '2'
                                )), 
                        ),                        
                        array(
                            'id' => 'gallery-loadmore-style',
                            'type' => 'button_set',
                            'title' => esc_html__('Portfolio loadmore style', 'bonfire'),
                            'options' => array(
                                '1' => esc_html__('Button style 1','bonfire'),
                                '2' => esc_html__('Button style 2','bonfire'),
                                ),
                            'default' => '1',                         
                        ), 
                        array(
                            'id'       => 'gallery_per_page',
                            'type'     => 'spinner', 
                            'title'    => esc_html__('Post show per page', 'bonfire'),
                            'default'  => '12',
                            'min'      => '1',
                            'step'     => '1',
                            'max'      => '20',
                        )
                    )                      
                ),
               array(
                    'icon_class' => 'icon',
                    'subsection' => true,
                    'title' => esc_html__('Single Portfolio', 'bonfire'),
                    'fields' => array(
                        array(
                            'id' => '1',
                            'type' => 'info',
                            'desc' => esc_html__('Portfolio detail page', 'bonfire')
                        ),
                        array(
                            'id' => 'single_gallery_style',
                            'type' => 'button_set',
                            'title' => esc_html__('Single gallery layout', 'bonfire'),
                            'options' => array(
                                    "1" => esc_html__("Layout 1","bonfire"),
                                    "2" => esc_html__("Layout 2","bonfire"),
                                ),
                            'default' => '1',                         
                        ), 
                        array(
                            'id'=>'gallery-share',
                            'type' => 'button_set',
                            'title' => esc_html__('Gallery Share Links', 'bonfire'),
                            'multi' => true,
                            'options'=> array(
                                'facebook' => esc_html__('Facebook', 'bonfire'),    
                                'twitter' => esc_html__('Twitter', 'bonfire'),
                                'pin' => esc_html__('Pinterest', 'bonfire'),
                                'insta' => esc_html__('Instagram', 'bonfire'),
                            ), 
                            'default' => array('facebook','twitter','pin','insta')
                        ),                        
                    )
                ),
                array(
                    'icon' => 'el-icon-shopping-cart',
                    'icon_class' => 'icon',
                    'title' => esc_html__('Shop', 'bonfire'),
                    'fields' => array(
                        array(
                            'id' => 'number-cate',
                            'type' => 'text',
                            'title' => esc_html__('[Desktop] Number of categories to show', 'bonfire'),
                            'default' => '4',
                            'desc'  => esc_html__('This option will work if you select to display categories in shop archive page.','bonfire'),
                        ),
						array(
                            'id' => 'product-cart',
                            'type' => 'switch',
                            'title' => esc_html__('Show Add to Cart button', 'bonfire'),
                            'default' => true,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire')
                        ),
                        array(
                            'id' => 'product-price',
                            'type' => 'switch',
                            'title' => esc_html__('Show Product Price', 'bonfire'),
                            'default' => true,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire')
                        ),                        
                        array(
                            'id' => 'product-label',
                            'type' => 'switch',
                            'title' => esc_html__('Show Product Label', 'bonfire'),
                            'default' => false,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire'),
                        ),
                    )
                ),
                array(
                    'icon_class' => 'icon',
                    'subsection' => true,
                    'title' => esc_html__('Product Archive', 'bonfire'),
                    'fields' => array( 
                        array(
                            'id' => 'shop-layout',
                            'type' => 'button_set',
                            'title' => esc_html__('Layout', 'bonfire'),
                            'options' => $page_layout,
                            'default' => 'fullwidth'
                        ),
                        array(
                            'id' => 'left-shop-sidebar',
                            'type' => 'select',
                            'title' => esc_html__('Select Left Sidebar', 'bonfire'),
                            'data' => 'sidebars',
                            'default' => ''
                        ),
                        array(
                            'id' => 'right-shop-sidebar',
                            'type' => 'select',
                            'title' => esc_html__('Select Right Sidebar', 'bonfire'),
                            'data' => 'sidebars',
                            'default' => ''
                        ),
						array(
                            'id' => 'product-breadcrumb',
                            'type' => 'switch',
                            'title' => esc_html__('Show Thumbnail Breadcrumb', 'bonfire'),
                            'default' => true,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire')
                        ),
                        array(
                            'id' => 'shop-slogan',
                            'type' => 'textarea',
                            'title' => esc_html__('Shop Description', 'bonfire'),
                            'default' => esc_html__('It started with a simple idea: Create quality, well-designed products that I wanted myself.','bonfire'),                          
                        ),
						array(
                            'id' => 'product-toolbar',
                            'type' => 'switch',
                            'title' => esc_html__('Show Toolbar', 'bonfire'),
                            'default' => true,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire')
                        ), 
                        array(
                            'id' => 'category-item',
                            'type' => 'text',
                            'title' => esc_html__('Products Per Page', 'bonfire'),
                            'desc' => esc_html__('Comma separated list of product counts.', 'bonfire'),
                            'default' => '8,16,24'
                        ),
                        array(
                            'id' => 'product-layouts',
                            'type' => 'button_set',
                            'title' => esc_html__('Product Layouts', 'bonfire'),
                            'options' => apr_product_type(),
                            'default' => 'only-grid',
                        ),
                        array(
                            'id' => 'product-cols',
                            'type' => 'button_set',
                            'title' => esc_html__('Product Columns', 'bonfire'),
                            'options' => apr_product_columns(),
                            'default' => '4',
                            'required' => array('product-layouts', 'equals', array(
                                    'only-grid'
                                )),                             
                        ),
                        array(
                            'id' => 'product-quickview',
                            'type' => 'switch',
                            'title' => esc_html__('Show Quickview', 'bonfire'),
                            'default' => true,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire'),
                        ),
                        array(
                            'id' => 'product-compare',
                            'type' => 'switch',
                            'title' => esc_html__('Show Compare', 'bonfire'),
                            'default' => true,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire')
                        ),
                        array(
                            'id' => 'product-wishlist',
                            'type' => 'switch',
                            'title' => esc_html__('Show Wishlist', 'bonfire'),
                            'default' => true,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire'),
                        ),  
                    )
                ),
                array(
                    'icon_class' => 'icon',
                    'subsection' => true,
                    'title' => esc_html__('Single Product', 'bonfire'),
                    'fields' => array(
                        array(
                            'id' => 'single-product-layout',
                            'type' => 'button_set',
                            'title' => esc_html__('Layout', 'bonfire'),
                            'options' => $page_layout,
                            'default' => 'fullwidth'
                        ),
                        array(
                            'id' => 'left-single-product-sidebar',
                            'type' => 'select',
                            'title' => esc_html__('Select Left Sidebar', 'bonfire'),
                            'data' => 'sidebars',
                            'default' => ''
                        ),
                        array(
                            'id' => 'right-single-product-sidebar',
                            'type' => 'select',
                            'title' => esc_html__('Select Right Sidebar', 'bonfire'),
                            'data' => 'sidebars',
                            'default' => ''
                        ),
                        array(
                            'id' => 'product-share',
                            'type' => 'switch',
                            'title' => esc_html__('Show Product share link', 'bonfire'),
                            'default' => true,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire'),
                        ),   
                        array(
                            'id' => 'product-related',
                            'type' => 'switch',
                            'title' => esc_html__('Show Related Products', 'bonfire'),
                            'default' => true,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire'),
                        ),
                        array(
                            'id' => 'product-reviewtab',
                            'type' => 'switch',
                            'title' => esc_html__('Remove Product Review tab', 'bonfire'),
                            'default' => false,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire'),
                        ),                                                    
                        array(
                            'id' => 'product-destab',
                            'type' => 'switch',
                            'title' => esc_html__('Remove Product Description tab', 'bonfire'),
                            'default' => false,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire'),
                        ),                          
                        array(
                            'id' => 'product-infotab',
                            'type' => 'switch',
                            'title' => esc_html__('Remove Additional Information tab', 'bonfire'),
                            'default' => false,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire'),
                        ),     
                        array(
                            'id' => 'product_tagtab',
                            'type' => 'switch',
                            'title' => esc_html__('Remove Tag Tab', 'bonfire'),
                            'default' => false,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire'),
                        ),  
                        array(
                            'id' => 'product-reviewtab-name',
                            'type' => 'text',
                            'title' => esc_html__('Rename Product Review Tab', 'bonfire'),
                            'default' => esc_html__('Reviews', 'bonfire')
                        ), 
                        array(
                            'id' => 'product-destab-name',
                            'type' => 'text',
                            'title' => esc_html__('Rename Product Description Tab', 'bonfire'),
                            'default' => esc_html__('Description', 'bonfire')
                        ), 
                        array(
                            'id' => 'product-infotab-name',
                            'type' => 'text',
                            'title' => esc_html__('Rename Additional Information Tab', 'bonfire'),
                            'default' => esc_html__('Additional info', 'bonfire')
                        ),  
                        array(
                            'id' => 'product-tagtab-name',
                            'type' => 'text',
                            'title' => esc_html__('Rename Tag Tab', 'bonfire'),
                            'default' => esc_html__('Tags', 'bonfire')
                        ),                                                                                                                                                                                      
                    )
                ),
                array(
                    'icon' => 'el-icon-cog',
                    'icon_class' => 'icon',
                    'title' => esc_html__('404 Page', 'bonfire'),
                    'customizer' => false,
                    'fields' => array(
                        array(
                            'id' => '404-bg-image',
                            'type' => 'media',
                            'url' => true,    
                            'readonly' => false,
                            'title' => esc_html__('Background image', 'bonfire'),
                            'desc' => esc_html__('Background image for 404 page', 'bonfire'),
                            'default' => array(
                                'url' => get_template_directory_uri() . '/images/404.jpg',
                            )                            
                        ),
                        array(
                            'id' => '404-title',
                            'type' => 'text',
                            'title' => esc_html__('404 title', 'bonfire'),
                            'default' => esc_html__("404", 'bonfire')
                        ),                         
                        array(
                            'id' => '404-content',
                            'type' => 'text',
                            'title' => esc_html__('404 content', 'bonfire'),
                            'default' => esc_html__("The page you're looking for cannot be found", 'bonfire')
                        ),  
                        array(
                            'id' => '404-color',
                            'type' => 'color',
                            'title' => esc_html__('Text color', 'bonfire'),
                            'default' => '#ffffff',
                            'validate' => 'color',
                            'transparent' => false,
                            'output' => array('border-color' => '.content-404 h1'),
                        ), 
                        array(
                            'id' => '404-overlay',
                            'type' => 'switch',
                            'title' => esc_html__('Enable background overlay', 'bonfire'),
                            'default' => true,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire'),
                        ), 
                        array(
                            'id'        => '404-overlay-color',
                            'type'      => 'color_rgba',
                            'title'     => 'Overlay background color',
                            'subtitle'  => 'Set color for background overlay color',                        
                            'output'    => array('background-color' => '.overlay404:before'),
                            'options'       => array(
                                'show_input'                => true,
                                'show_initial'              => true,
                                'show_alpha'                => true,
                                'show_palette'              => true,
                                'show_palette_only'         => false,
                                'show_selection_palette'    => true,
                                'max_palette_size'          => 10,
                                'allow_empty'               => true,
                                'clickout_fires_change'     => false,
                                'choose_text'               => 'Choose',
                                'cancel_text'               => 'Cancel',
                                'show_buttons'              => true,
                                'use_extended_classes'      => true,
                                'palette'                   => null,  // show default
                                'input_text'                => 'Select Color'
                            ),
                            'required' =>    array('404-overlay', 'equals', true),                     
                        ),                                                                       
                        array(
                            'id' => '404_header',
                            'type' => 'image_select',
                            'options' => $this->apr_header_types(),
                            'default' => '3',
                            'title' => esc_html__('Header Type', 'bonfire'),
                        ),  
                        array(
                            'id' => '404_footer',
                            'type' => 'image_select',
                            'options' => $this->apr_footer_types(),
                            'default' => '1',
                            'title' => esc_html__('Footer Type', 'bonfire'),
                        ),                                                                                                                    
                    )
                ),                        
                array(
                    'icon' => 'el-icon-cog',
                    'icon_class' => 'icon',
                    'customizer' => false,
                    'title' => esc_html__('Coming soon', 'bonfire'),
                    'fields' => array(
                        array(
                            'id' => 'under-contr-mode',
                            'type' => 'switch',
                            'title' => esc_html__('Activate under construction mode', 'bonfire'),
                            'default' => false,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire'),
                        ),                                                            
                        array(
                            'id' => 'under-bg-image',
                            'type' => 'media',
                            'url' => true,
                            'readonly' => false,
                            'title' => esc_html__('Background image', 'bonfire'),
                            'desc' => esc_html__('Background image for coming soon page', 'bonfire'),
                            'default' => array(
                                'url' => get_template_directory_uri() . '/images/coming-soon.jpg',
                            ),
                        ),
                        array(
                            'id' => 'coming-overlay-color',
                            'type' => 'color',
                            'title' => esc_html__('Background overlay color', 'bonfire'),
                            'default' => '#000000',
                            'validate' => 'color',
                            'transparent' => true,
                        ),                        
                        array(
                            'id' => "under-contr-title",
                            'type' => 'textarea',
                            'title' => esc_html__('Big Title', 'bonfire'),
                            'default' => wp_kses( __('<h3>Launching</h3><h2>Very soon</h2>' , 'bonfire'), 
                                array(
                                'a' => array(
                                    'href' => array('callto'=> array()),
                                    'title' => array(),
                                    'target' => array(),
                                ),
                                'i' => array(
                                    'class' => array(),
                                    'aria-hidden' => array(),
                                ),
                                'h2' => array(
                                    'class' => array(),
                                ),
                                'h3' => array(
                                    'class' => array(),
                                ),
                            )),
                        ),
                        array(
                            'id' => '1',
                            'type' => 'info',
                            'desc' => esc_html__('Countdown Timer', 'bonfire')
                        ),
                        array(
                            'id' => 'under-display-countdown',
                            'type' => 'switch',
                            'title' => esc_html__('Display countdown timer', 'bonfire'),
                            'default' => true,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire'),
                        ),
                         array(
                            'id' => "under-end-date",
                            'type' => 'date',
                            'title' => esc_html__('End date', 'bonfire'),
                            'default' => '12/28/2017',
                            'required' => array('under-display-countdown', 'equals', true),
                        ),
                        array(
                            'id' => "under-contr-day",
                            'type' => 'text',
                            'title' => esc_html__('Text display under day number', 'bonfire'),
                            'default' => esc_html__('D', 'bonfire')
                        ),  
                        array(
                            'id' => "under-contr-hour",
                            'type' => 'text',
                            'title' => esc_html__('Text display under hour number', 'bonfire'),
                            'default' => esc_html__('H', 'bonfire')
                        ),
                        array(
                            'id' => "under-contr-min",
                            'type' => 'text',
                            'title' => esc_html__('Text display under minute number', 'bonfire'),
                            'default' => esc_html__('M', 'bonfire')
                        ),
                        array(
                            'id' => "under-contr-sec",
                            'type' => 'text',
                            'title' => esc_html__('Text display under secs number', 'bonfire'),
                            'default' => esc_html__('S', 'bonfire')
                        ),                                                                           
                        array(
                            'id' => 'under-mail',
                            'type' => 'switch',
                            'title' => esc_html__('Display subcribe form', 'bonfire'),
                            'default' => true,
                            'on' => esc_html__('Yes', 'bonfire'),
                            'off' => esc_html__('No', 'bonfire'),
                        ),
                        array(
                            'id' => "coming_subcribe_text",
                            'type' => 'text',
                            'title' => esc_html__('Submit button text in subcribe form', 'bonfire'),
                            'default' =>  esc_html__('Notify me' , 'bonfire'), 
                        ),                        
                    )
                ),
            );
            return $sections;
        }

        protected function apr_add_header_section_options() {
            $apr_seclect_slider = apr_seclect_slider();
            unset($apr_seclect_slider['default']);
            $header = array(
                'icon' => 'el-icon-edit',
                'icon_class' => 'icon',
                'customizer' => false,
                'title' => esc_html__('Header', 'bonfire'),
                'fields' => array(
                    array(
                        'id' => 'header-type',
                        'type' => 'image_select',
                        'title' => esc_html__('Header Type', 'bonfire'),
                        'subtitle' => esc_html__('Each page will have option for select header type. Header selection in each page will have higher priority than this general selection.','bonfire'),
                        'options' => $this->apr_header_types(),
                        'default' => '1',
                    ),                           
                    array(
                        'id' => 'logo3',
                        'type' => 'media',
                        'url' => true,
                        'readonly' => false,
                        'title' => esc_html__('Logo', 'bonfire'),
                        'required' => array(
                                    array('header-type', 'equals', array(
                                    '3'
                                )),
                            ),
                        'default' => array(
                            'url' => get_template_directory_uri() . '/images/logo3.png',
                            'height' => 50,
                            'wide' => 50
                        )
                    ), 
                    array(
                        'id' => 'logo4',
                        'type' => 'media',
                        'url' => true,
                        'readonly' => false,
                        'title' => esc_html__('Logo', 'bonfire'),
                        'required' => array(
                                    array('header-type', 'equals', array(
                                    '4'
                                )),
                            ),
                        'default' => array(
                            'url' => get_template_directory_uri() . '/images/logo4.png',
                            'height' => 50,
                            'wide' => 50
                        )
                    ), 
                     array(
                        'id' => 'logo6',
                        'type' => 'media',
                        'url' => true,
                        'readonly' => false,
                        'title' => esc_html__('Logo', 'bonfire'),
                        'required' => array(
                                    array('header-type', 'equals', array(
                                    '6'
                                )),
                            ),
                        'default' => array(
                            'url' => get_template_directory_uri() . '/images/logo6.png',
                            'height' => 167,
                            'wide' => 56
                        )
                    ),
                    array(
                        'id' => 'select-slider',
                        'type' => 'select',
                        'title' => esc_html__('Select Top Slider', 'bonfire'),
                        'options' => $apr_seclect_slider,
                        'desc' => esc_html__('Choose a slider to display at the top of pages. You can create a block in Static Block/Add New.', 'bonfire'),
                        'default' => '',
                        'required' => array(
                                array('header-type', 'equals', array(
                                '9'
                            )),
                        ),
                    ),
                    array(
                        'id' => 'header-fixed',
                        'type' => 'switch',
                        'title' => esc_html__('Enable Fixed Header (Header displays over content)', 'bonfire'),
                        'default' => false,
                    ),
                    array(
                        'id' => 'header_layout_style',
                        'type' => 'button_set',
                        'title' => esc_html__('Header Layout Style', 'bonfire'),
                        'options' => array(
                                "1" => esc_html__("Wide","bonfire"),
                                "2" => esc_html__("FullWidth","bonfire"),
                                "3" => esc_html__("Boxed","bonfire"),
                            ),
                        'default' => '2',
                        'required' => array(
                                array('header-type', 'equals', array(
                                '2'
                            )),
                        ),
                    ), 
                    array(
                        'id' => 'header_layout_style_2',
                        'type' => 'button_set',
                        'title' => esc_html__('Header Layout Style', 'bonfire'),
                        'options' => array(
                                "1" => esc_html__("Wide","bonfire"),
                                "2" => esc_html__("FullWidth","bonfire"),
                                "3" => esc_html__("Boxed","bonfire"),
                            ),
                        'default' => '3',
                        'required' => array(
                                array('header-type', 'equals', array(
                                '1','4'
                            )),
                        ),
                    ),
                    array(
                        'id' => 'header_layout_style_3',
                        'type' => 'button_set',
                        'title' => esc_html__('Header Layout', 'bonfire'),
                        'options' => array(
                                "1" => esc_html__("Wide","bonfire"),
                                "2" => esc_html__("FullWidth","bonfire"),
                                "3" => esc_html__("Boxed","bonfire"),
                            ),
                        'default' => '1',
                        'required' => array(
                                array('header-type', 'equals', array(
                                '5','7','3'
                            )),
                        ),
                    ),  
                    array(
                        'id' => 'header1-search',
                        'type' => 'switch',
                        'title' => esc_html__('Show Search', 'bonfire'),                        
                        'default' => true,
                        'required' => array(
                                array('header-type', 'equals', array(
                                '1'
                            )), 
                        ),                            
                    ), 
                    array(
                        'id' => 'header2-search',
                        'type' => 'switch',
                        'title' => esc_html__('Show Search', 'bonfire'),                        
                        'default' => true,
                        'required' => array(
                                array('header-type', 'equals', array(
                                '2'
                            )), 
                        ),                            
                    ), 
                    array(
                        'id' => 'header3-search',
                        'type' => 'switch',
                        'title' => esc_html__('Show Search', 'bonfire'),                        
                        'default' => false,
                        'required' => array(
                                array('header-type', 'equals', array(
                                '3'
                            )), 
                        ),                            
                    ),
                    array(
                        'id' => 'header4-search',
                        'type' => 'switch',
                        'title' => esc_html__('Show Search', 'bonfire'),                        
                        'default' => false,
                        'required' => array(
                                array('header-type', 'equals', array(
                                '4'
                            )),  
                        ),                       
                    ), 
                    array(
                        'id' => 'header5-search',
                        'type' => 'switch',
                        'title' => esc_html__('Show Search', 'bonfire'),                        
                        'default' => true,
                        'required' => array(
                                array('header-type', 'equals', array(
                                '5'
                            )),  
                        ),                       
                    ), 
                    array(
                        'id' => 'header6-search',
                        'type' => 'switch',
                        'title' => esc_html__('Show Search', 'bonfire'),                        
                        'default' => false,
                        'required' => array(
                                array('header-type', 'equals', array(
                                '6'
                            )),  
                        ),                       
                    ), 
                    array(
                        'id' => 'header-search-icon',
                        'type' => 'text',
                        'title' => esc_html__('Icon Search', 'bonfire'),   
                        'default' => 'ion-ios-search',
                        'placeholder' => esc_html__('lnr lnr-magnifier', 'bonfire'),
                        'required' => array('header-search', 'equals', array(
                            true
                        )), 
                        'desc' => wp_kses(__('Add icon class you want here. You can find a lot of icons in these links <a target="_blank" href="http://fontawesome.io/icons/">Awesome icon</a> or <a target="_blank" href="https://linearicons.com/free">Linearicons </a>, <a target="_blank" href="http://themes-pixeden.com/font-demos/7-stroke/">Pe stroke icon7 </a> and <a target="_blank" href="https://www.dropbox.com/s/oy8lsb7u4eli7rt/bonfire_font.png?dl=0">Bonfire icon list </a>','bonfire'),array(
                                'a' => array(
                                    'href'=>array(),
                                    'target' => array(),
                                    ),
                            )) 
                    ),  
                    array(
                        'id' => 'header-search-icon-hidden',
                        'type' => 'text',
                        'title' => esc_html__('Icon Search', 'bonfire'),  
                        'default' => 'ion-ios-search',
                        'placeholder' => esc_html__('ion-ios-search', 'bonfire'),
                        'required' => array('header-search-hidden', 'equals', array(
                            true
                        )), 
                        'desc' => wp_kses(__('Add icon class you want here. You can find a lot of icons in these links <a target="_blank" href="http://fontawesome.io/icons/">Awesome icon</a> or <a target="_blank" href="https://linearicons.com/free">Linearicons </a>, <a target="_blank" href="http://themes-pixeden.com/font-demos/7-stroke/">Pe stroke icon7 </a> and <a target="_blank" href="https://www.dropbox.com/s/oy8lsb7u4eli7rt/bonfire_font.png?dl=0">Bonfire icon list </a>','bonfire'),array(
                                'a' => array(
                                    'href'=>array(),
                                    'target' => array(),
                                    ),
                            ))                         
                    ),
                    array(
                        'id' => 'header_search_style',
                        'type' => 'button_set',
                        'title' => esc_html__('Header Search Style', 'bonfire'),
                        'options' => array(
                                "1" => esc_html__("Standard","bonfire"),
                                "2" => esc_html__("Sidebar","bonfire"),
                            ),
                        'default' => '1', 
                        'required' => array(
                                array('header-type', 'equals', array(
                                '1', '3','5','9'
                            )),
                        ),
                    ), 
                    array(
                        'id' => 'header_search_style_2',
                        'type' => 'button_set',
                        'title' => esc_html__('Header Search Style', 'bonfire'),
                        'options' => array(
                                "1" => esc_html__("Standard","bonfire"),
                                "2" => esc_html__("Sidebar","bonfire"),
                            ),
                        'default' => '2',  
                        'required' => array(
                                array('header-type', 'equals', array(
                                '2', '4','8'
                            )),
                        ),
                    ),   
                    array(
                        'id' => 'header_search_type',
                        'type' => 'button_set',
                        'title' => esc_html__('Header Search Type', 'bonfire'),
                        'options' => array(
                                "1" => esc_html__("Product (if Woocommerce enable)","bonfire"),
                                "2" => esc_html__("Blog","bonfire"),
                            ),
                        'default' => '1',                         
                    ),
                    array(
                        'id' => 'header1-minicart',
                        'type' => 'switch',
                        'title' => esc_html__('Show Mini Cart', 'bonfire'),                      
                        'default' => true,
                        'required' => array(
                                array('header-type', 'equals', array(
                                '1'
                            )), 
                        ),                           
                    ),
                    array(
                        'id' => 'header2-minicart',
                        'type' => 'switch',
                        'title' => esc_html__('Show Mini Cart', 'bonfire'),                      
                        'default' => true,
                        'required' => array(
                                array('header-type', 'equals', array(
                                '2'
                            )), 
                        ),                           
                    ),
                    array(
                        'id' => 'header3-minicart',
                        'type' => 'switch',
                        'title' => esc_html__('Show Mini Cart', 'bonfire'),                      
                        'default' => true,
                        'required' => array(
                                array('header-type', 'equals', array(
                                '3'
                            )), 
                        ),                           
                    ),
                    array(
                        'id' => 'header4-minicart',
                        'type' => 'switch',
                        'title' => esc_html__('Show Mini Cart', 'bonfire'),                      
                        'default' => true,
                        'required' => array(
                                array('header-type', 'equals', array(
                                '4'
                            )), 
                        ),                           
                    ),
                    array(
                        'id' => 'header5-minicart',
                        'type' => 'switch',
                        'title' => esc_html__('Show Mini Cart', 'bonfire'),                      
                        'default' => true,
                        'required' => array(
                                array('header-type', 'equals', array(
                                '5'
                            )), 
                        ),                           
                    ),
                    array(
                        'id' => 'header6-minicart',
                        'type' => 'switch',
                        'title' => esc_html__('Show Mini Cart', 'bonfire'),                      
                        'default' => true,
                        'required' => array(
                                array('header-type', 'equals', array(
                                '6'
                            )), 
                        ),                           
                    ),
                    array(
                        'id' => 'header-cart-icon',
                        'type' => 'text',
                        'title' => esc_html__('Icon Mini Cart', 'bonfire'),  
                        'default' => 'ion-ios-cart-outline',
                        'placeholder' => esc_html__('ion-ios-cart-outline', 'bonfire'),
                        'required' => array('header-minicart', 'equals', array(
                            true
                        )), 
                        'desc' => wp_kses(__('Add icon class you want here. You can find a lot of icons in these links <a target="_blank" href="http://fontawesome.io/icons/">Awesome icon</a> or <a target="_blank" href="https://linearicons.com/free">Linearicons </a>, <a target="_blank" href="http://themes-pixeden.com/font-demos/7-stroke/">Pe stroke icon7 </a> and <a target="_blank" href="https://www.dropbox.com/s/oy8lsb7u4eli7rt/bonfire_font.png?dl=0">Bonfire icon list </a>','bonfire'),array(
                                'a' => array(
                                    'href'=>array(),
                                    'target' => array(),
                                    ),
                            ))                         
                    ),
                    array(
                        'id' => 'header-cart-icon-hidden',
                        'type' => 'text',
                        'title' => esc_html__('Icon Mini Cart', 'bonfire'),   
                        'placeholder' => esc_html__('ion-ios-cart-outline', 'bonfire'),
                        'default' => 'ion-ios-cart-outline',
                        'required' => array('header-minicart-hidden', 'equals', array(
                            true
                        )), 
                        'desc' => wp_kses(__('Add icon class you want here. You can find a lot of icons in these links <a target="_blank" href="http://fontawesome.io/icons/">Awesome icon</a> or <a target="_blank" href="https://linearicons.com/free">Linearicons </a>, <a target="_blank" href="http://themes-pixeden.com/font-demos/7-stroke/">Pe stroke icon7 </a> and <a target="_blank" href="https://www.dropbox.com/s/oy8lsb7u4eli7rt/bonfire_font.png?dl=0">Bonfire icon list </a>','bonfire'),array(
                                'a' => array(
                                    'href'=>array(),
                                    'target' => array(),
                                    ),
                            ))                         
                    ),
                    
                    array(
                        'id' => 'header-myaccount',
                        'type' => 'switch',
                        'title' => esc_html__('Show My Account', 'bonfire'),                        
                        'default' => false,
                        'required' => array(
                                array('header-type', 'equals', array(
                                '1','2','3','4','5','6','7','8','9'
                            )), 
                        ),                            
                    ),
                    array(
                        'id' => 'header-myaccount-icon',
                        'type' => 'text',
                        'title' => esc_html__('Icon My Account', 'bonfire'),   
                        'placeholder' => esc_html__('ion-ios-person-outline', 'bonfire'),
                        'default' => 'ion-android-person',
                        'required' => array('header-myaccount', 'equals', array(
                            true
                        )),
                        'desc' => wp_kses(__('Add icon class you want here. You can find a lot of icons in these links <a target="_blank" href="http://fontawesome.io/icons/">Awesome icon</a> or <a target="_blank" href="https://linearicons.com/free">Linearicons </a>, <a target="_blank" href="http://themes-pixeden.com/font-demos/7-stroke/">Pe stroke icon7 </a> and <a target="_blank" href="https://www.dropbox.com/s/oy8lsb7u4eli7rt/bonfire_font.png?dl=0">Bonfire icon list </a>','bonfire'),array(
                                'a' => array(
                                    'href'=>array(),
                                    'target' => array(),
                                    ),
                            ))                          
                    ),
                    array(
                        'id' => 'header-social',
                        'type' => 'switch',
                        'title' => esc_html__('Show Social Link', 'bonfire'),                        
                        'default' => false,
                    ), 
                    array(
                        'id' => 'social-header-twitter',
                        'type' => 'text',
                        'title' => esc_html__('Twitter', 'bonfire'),
                        'placeholder' => esc_html__('http://', 'bonfire'), 
                        'required' => array('header-social', 'equals', array(
                            true
                        )),  
                    ),
                    array(
                        'id' => 'social-header-instagram',
                        'type' => 'text',
                        'title' => esc_html__('Instagram', 'bonfire'),
                        'placeholder' => esc_html__('http://', 'bonfire'),
                        'required' => array('header-social', 'equals', array(
                            true
                        )),
                    ),
                    array(
                        'id' => 'social-header-facebook',
                        'type' => 'text',
                        'title' => esc_html__('Facebook', 'bonfire'),
                        'placeholder' => esc_html__('http://', 'bonfire'),
                        'required' => array('header-social', 'equals', array(
                            true
                        )),
                    ),
                    array(
                        'id' => 'social-header-google',
                        'type' => 'text',
                        'title' => esc_html__('Google Plus', 'bonfire'),
                        'placeholder' => esc_html__('http://', 'bonfire'),
                        'required' => array('header-social', 'equals', array(
                            true
                        )),
                    ),        
                    array(
                        'id' => 'social-header-pinterest',
                        'type' => 'text',
                        'title' => esc_html__('Pinterest', 'bonfire'),
                        'placeholder' => esc_html__('http://', 'bonfire'),
                        'required' => array('header-social', 'equals', array(
                            true
                        )),
                    ),                                
                    array(
                        'id' => 'header-sticky',
                        'type' => 'switch',
                        'title' => esc_html__('Enable Sticky', 'bonfire'),
                        'default' => true
                    ),   
                    array(
                        'id' => 'header-sticky-mobile',
                        'type' => 'switch',
                        'required' => array('header-sticky', 'equals', 1,),
                        'title' => esc_html__('Enable Sticky On Mobile ', 'bonfire'),
                        'default' => true
                    ),      
                    array(
                        'id' => 'header_postion',
                        'type' => 'button_set',
                        'title' => esc_html__('Header Mobile Position', 'bonfire'),
                        'options' => array(
                                "1" => esc_html__("Top","bonfire"),
                                "2" => esc_html__("Bottom","bonfire"),
                            ),
                        'default' => '1',                         
                    ),   
                ),
            );

            return $header;
        }

        public function apr_get_setting_arguments() {
            $theme = wp_get_theme();
            $args = array(
                // TYPICAL -> Change these values as you need/desire
                'opt_name' => 'apr_settings',
                'display_name' => esc_html__('Apr', 'bonfire'),
                'display_version' => $theme->get('Version'),
                'menu_type' => 'menu',
                'allow_sub_menu' => true,
                'menu_title' => esc_html__('Apr Options', 'bonfire'),
                'page_title' => esc_html__('Apr', 'bonfire'),
                'google_api_key' => '',
                'google_update_weekly' => false,
                'async_typography' => true,
                'admin_bar' => true,
                'admin_bar_icon' => 'dashicons-admin-generic',
                'admin_bar_priority' => 50,
                'global_variable' => '',
                'dev_mode' => false,
                'update_notice' => true,
                'customizer' => true,
                'page_priority' => null,
                'page_parent' => 'themes.php',
                'page_permissions' => 'manage_options',
                'menu_icon' => '',
                'last_tab' => '',
                'page_icon' => 'icon-themes',
                'page_slug' => '',
                'save_defaults' => true,
                'default_show' => false,
                'default_mark' => '',
                'show_import_export' => true,
                'transient_time' => 60 * MINUTE_IN_SECONDS,
                'output' => true,
                'output_tag' => true,
                'database' => '',
                'use_cdn' => true,
                // HINTS
                'hints' => array(
                    'icon' => 'el el-question-sign',
                    'icon_position' => 'right',
                    'icon_color' => 'lightgray',
                    'icon_size' => 'normal',
                    'tip_style' => array(
                        'color' => 'red',
                        'shadow' => true,
                        'rounded' => false,
                        'style' => '',
                    ),
                    'tip_position' => array(
                        'my' => 'top left',
                        'at' => 'bottom right',
                    ),
                    'tip_effect' => array(
                        'show' => array(
                            'effect' => 'slide',
                            'duration' => '500',
                            'event' => 'mouseover',
                        ),
                        'hide' => array(
                            'effect' => 'slide',
                            'duration' => '500',
                            'event' => 'click mouseleave',
                        ),
                    ),
                )
            );
            return $args;
        }

        protected function apr_header_types() {
            return array(
                '1' => array('alt' => esc_html__('Header Type 1', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/headers/header-1.jpg'),
                '2' => array('alt' => esc_html__('Header Type 2', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/headers/header-2.jpg'),
                '3' => array('alt' => esc_html__('Header Type 3', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/headers/header-3.jpg'),
                '4' => array('alt' => esc_html__('Header Type 4', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/headers/header-4.jpg'),                                           
                '5' => array('alt' => esc_html__('Header Type 5', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/headers/header-5.jpg'),  

                 '6' => array('alt' => esc_html__('Header Type 6', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/headers/header-6.jpg'),                                         
            );
        }

        protected function apr_footer_types() {
            return array(
                '1' => array('alt' => esc_html__('Footer Type 1', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/footers/footer-1.jpg'),
                '2' => array('alt' => esc_html__('Footer Type 2', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/footers/footer-2.jpg'),
                '3' => array('alt' => esc_html__('Footer Type 3', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/footers/footer-3.jpg'),
            );
        }
        
        protected function apr_preload_types() {
            return array(
                '1' => array('alt' => esc_html__('Preload Type 1', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/preload/preload-1.jpg'),
                '2' => array('alt' => esc_html__('Preload Type 2', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/preload/preload-2.jpg'),
                '3' => array('alt' => esc_html__('Preload Type 3', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/preload/preload-3.jpg'),
                '4' => array('alt' => esc_html__('Preload Type 4', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/preload/preload-4.jpg'),
                '5' => array('alt' => esc_html__('Preload Type 5', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/preload/preload-5.jpg'),                                                
                '6' => array('alt' => esc_html__('Preload Type 6', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/preload/preload-6.jpg'),                                                
                '7' => array('alt' => esc_html__('Preload Type 7', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/preload/preload-7.jpg'),                                                
                '8' => array('alt' => esc_html__('Preload Type 8', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/preload/preload-8.jpg'),                                                
                '9' => array('alt' => esc_html__('Preload Type 9', 'bonfire'), 'img' => get_template_directory_uri() . '/inc/admin/settings/preload/preload-9.jpg'),                                                
            );
        }

    }

    
    function apr_get_framework_settings() {
        global $aprReduxSettings;
        $aprReduxSettings = new Framework_Apr_Settings();
        return $aprReduxSettings;
    }
    apr_get_framework_settings();
}